@@ -30,7 +30,8 @@ coxpenal.fit <- function(x, y, strata, offset, init, control,
 	    }
 	status <- y[,3]
 	andersen <- TRUE
-	routines <- paste('agfit5', c('a', 'b', 'c'), sep='_')
+#	routines <- paste('agfit5', c('a', 'b', 'c'), sep='_')
+#        routines <- list(Cagfit5a, Cagfit5b, Cagfit5c)
         }
     else {
 	if (length(strata) ==0) {
@@ -44,7 +45,8 @@ coxpenal.fit <- function(x, y, strata, offset, init, control,
 	    }
 	status <- y[,2]
 	andersen <- FALSE
-	routines <- paste('coxfit5', c('a', 'b', 'c'), sep='_')
+#	routines <- paste('coxfit5', c('a', 'b', 'c'), sep='_')
+#        routines <- list(Ccoxfit5a, Ccoxfit5b, Ccoxfit5c)
         }
 
     n.eff <- sum(y[,ncol(y)])  #effective n for a Cox model is #events
@@ -290,26 +292,45 @@ coxpenal.fit <- function(x, y, strata, offset, init, control,
     #
     # Have C store the data, and get the loglik for beta=initial, frailty=0
     #
-    coxfit <- .C(routines[1],
-                       as.integer(n),
-                       as.integer(nvar), 
-                       as.double(y),
-                       x= as.double(xx) ,
-                       as.double(offset),
-                       as.double(weights),
-		       as.integer(newstrat),
-		       as.integer(sorted-1),
-                       means= double(nvar),
-                       coef= as.double(init),
-                       u = double(nvar),
-		       loglik=double(1),
-		       as.integer(method=='efron'),
-		       as.integer(ptype),
-		       as.integer(full.imat),
-		       as.integer(nfrail),
-		       as.integer(frailx),
-                 #R callback additions
-                 f.expr1,f.expr2,rho)
+    if (andersen) coxfit <- .C(Cagfit5a,
+                               as.integer(n),
+                               as.integer(nvar), 
+                               as.double(y),
+                               x= as.double(xx) ,
+                               as.double(offset),
+                               as.double(weights),
+                               as.integer(newstrat),
+                               as.integer(sorted-1),
+                               means= double(nvar),
+                               coef= as.double(init),
+                               u = double(nvar),
+                               loglik=double(1),
+                               as.integer(method=='efron'),
+                               as.integer(ptype),
+                               as.integer(full.imat),
+                               as.integer(nfrail),
+                               as.integer(frailx),
+                               #R callback additions
+                               f.expr1,f.expr2,rho)
+    else       coxfit <- .C(Ccoxfit5a, 
+                               as.integer(n),
+                               as.integer(nvar), 
+                               as.double(y),
+                               x= as.double(xx) ,
+                               as.double(offset),
+                               as.double(weights),
+                               as.integer(newstrat),
+                               as.integer(sorted-1),
+                               means= double(nvar),
+                               coef= as.double(init),
+                               u = double(nvar),
+                               loglik=double(1),
+                               as.integer(method=='efron'),
+                               as.integer(ptype),
+                               as.integer(full.imat),
+                               as.integer(nfrail),
+                               as.integer(frailx),
+                               f.expr1,f.expr2,rho)
 
     loglik0 <- coxfit$loglik
     means   <- coxfit$means
@@ -321,25 +342,42 @@ coxpenal.fit <- function(x, y, strata, offset, init, control,
     iterfail <- NULL
     thetasave <- unlist(thetalist)
     for (outer in 1:control$outer.max) {
-        coxfit <- .C(routines[2], 
-		        iter=as.integer(control$iter.max),
-			as.integer(n),
-			as.integer(nvar),
-		        as.integer(newstrat),
-			coef = as.double(init),
-		        u    = double(nvar+nfrail),
-			hmat = double(nvar*(nvar+nfrail)),
-			hinv = double(nvar*(nvar+nfrail)),
-			loglik = double(1),
-			flag = integer(1),
-			as.double(control$eps),
-		        as.double(control$toler.chol),
-			as.integer(method=='efron'),
-			as.integer(nfrail),
-		        fcoef = as.double(finit),
-			fdiag = double(nfrail+nvar),
-                     ## R additions
-                     f.expr1,f.expr2,rho)
+        if (andersen)  coxfit <- .C(Cagfit5b,  
+                                    iter=as.integer(control$iter.max),
+                                    as.integer(n),
+                                    as.integer(nvar),
+                                    as.integer(newstrat),
+                                    coef = as.double(init),
+                                    u    = double(nvar+nfrail),
+                                    hmat = double(nvar*(nvar+nfrail)),
+                                    hinv = double(nvar*(nvar+nfrail)),
+                                    loglik = double(1),
+                                    flag = integer(1),
+                                    as.double(control$eps),
+                                    as.double(control$toler.chol),
+                                    as.integer(method=='efron'),
+                                    as.integer(nfrail),
+                                    fcoef = as.double(finit),
+                                    fdiag = double(nfrail+nvar),
+                                    f.expr1,f.expr2,rho)
+        else   coxfit <- .C(Ccoxfit5b,  
+                                    iter=as.integer(control$iter.max),
+                                    as.integer(n),
+                                    as.integer(nvar),
+                                    as.integer(newstrat),
+                                    coef = as.double(init),
+                                    u    = double(nvar+nfrail),
+                                    hmat = double(nvar*(nvar+nfrail)),
+                                    hinv = double(nvar*(nvar+nfrail)),
+                                    loglik = double(1),
+                                    flag = integer(1),
+                                    as.double(control$eps),
+                                    as.double(control$toler.chol),
+                                    as.integer(method=='efron'),
+                                    as.integer(nfrail),
+                                    fcoef = as.double(finit),
+                                    fdiag = double(nfrail+nvar),
+                                    f.expr1,f.expr2,rho)
 
 	iter <- outer
 	iter2 <- iter2 + coxfit$iter
@@ -416,7 +454,12 @@ coxpenal.fit <- function(x, y, strata, offset, init, control,
         }
 
     # release the memory
-    expect <- .C(routines[3], as.integer(n),
+    if (andersen) expect <- .C(Cagfit5c, as.integer(n),
+		             as.integer(nvar),
+		             as.integer(newstrat),
+		             as.integer(method=='efron'),
+		             expect= double(n))$expect
+    else   expect <- .C(Ccoxfit5c, as.integer(n),
 		             as.integer(nvar),
 		             as.integer(newstrat),
 		             as.integer(method=='efron'),
